/*
 * SPDX-FileCopyrightText: Copyright (c) 2003-2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 * SPDX-License-Identifier: MIT
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the Software),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __ls10_dev_ingress_ip_h__
#define __ls10_dev_ingress_ip_h__
/* This file is autogenerated.  Do not edit */
#define NV_INGRESS          0x00001fff:0x00001000 /* RW--D */
#define NV_INGRESS_REQRSPMAPADDR                           0x00001080      /* RW-4R */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS               13:0            /* RWEVF */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_NORMREMAPTAB_DEPTH 0x00000fff /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_EXTAREMAPTAB_DEPTH 0x0000003f /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_EXTBREMAPTAB_DEPTH 0x0000003f /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_RID_TAB_DEPTH 0x000007ff      /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_ADDRESS_RLAN_TAB_DEPTH 0x000007ff     /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL                   18:16           /* RWEVF */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL_SELECTSNORMREMAPRAM 0x00000000    /* RWE-V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL_SELECTSRIDROUTERAM 0x00000001     /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL_SELECTSRLANROUTERAM 0x00000002    /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL_SELECTSEXTAREMAPRAM 0x00000003    /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_RAM_SEL_SELECTSEXTBREMAPRAM 0x00000004    /* RW--V */
#define NV_INGRESS_REQRSPMAPADDR_AUTO_INCR                 31:31           /* RWEVF */
#define NV_INGRESS_REQRSPMAPADDR_AUTO_INCR_ENABLE          0x00000001      /* RWE-V */
#define NV_INGRESS_REQRSPMAPADDR_AUTO_INCR_DISABLE         0x00000000      /* RW--V */
#define NV_INGRESS_MCREMAPTABADDR                          0x00001084      /* RW-4R */
#define NV_INGRESS_MCREMAPTABADDR_RAM_ADDRESS              6:0             /* RWEVF */
#define NV_INGRESS_MCREMAPTABADDR_RAM_ADDRESS_INIT         0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABADDR_RAM_ADDRESS_MCREMAPTAB_DEPTH 0x0000007f  /* RW--V */
#define NV_INGRESS_MCREMAPTABADDR_AUTO_INCR                31:31           /* RWEVF */
#define NV_INGRESS_MCREMAPTABADDR_AUTO_INCR_ENABLE         0x00000001      /* RWE-V */
#define NV_INGRESS_MCREMAPTABADDR_AUTO_INCR_DISABLE        0x00000000      /* RW--V */
#define NV_INGRESS_REMAPTABDATA0                           0x00001090      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA0_RMAP_ADDR                 12:0            /* RWEVF */
#define NV_INGRESS_REMAPTABDATA0_RMAP_ADDR_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA0_IRL_SEL                   16:15           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA0_IRL_SEL_SELECTNONE        0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA0_IRL_SEL_SELECTIRL0        0x00000001      /* RW--V */
#define NV_INGRESS_REMAPTABDATA0_IRL_SEL_SELECTIRL1        0x00000002      /* RW--V */
#define NV_INGRESS_REMAPTABDATA0_IRL_SEL_ENABLEERRRSP      0x00000003      /* RW--V */
#define NV_INGRESS_REMAPTABDATA0_ECC                       30:22           /* R-EVF */
#define NV_INGRESS_REMAPTABDATA0_ECC_INIT                  0x00000000      /* R-E-V */
#define NV_INGRESS_REMAPTABDATA0_ACLVALID                  31:31           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA0_ACLVALID_INVALID          0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA0_ACLVALID_VALID            0x00000001      /* RW--V */
#define NV_INGRESS_REMAPTABDATA1                           0x00001094      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA1_REQCTXT_MSK               15:0            /* RWEVF */
#define NV_INGRESS_REMAPTABDATA1_REQCTXT_MSK_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA1_REQCTXT_CHK               31:16           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA1_REQCTXT_CHK_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA2                           0x00001098      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA2_REQCTXT_REP               15:0            /* RWEVF */
#define NV_INGRESS_REMAPTABDATA2_REQCTXT_REP_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA3                           0x0000109c      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA3_ADR_BASE                  15:0            /* RWEVF */
#define NV_INGRESS_REMAPTABDATA3_ADR_BASE_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA3_ADR_LIMIT                 31:16           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA3_ADR_LIMIT_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA4                           0x000010a0      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA4_TGTID                     10:0            /* RWEVF */
#define NV_INGRESS_REMAPTABDATA4_TGTID_INIT                0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA4_RFUNC                     21:15           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA4_RFUNC_INIT                0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA4_RSVD                      31:31           /* RWEVF */
#define NV_INGRESS_REMAPTABDATA4_RSVD_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA5                           0x000010a4      /* RW-4R */
#define NV_INGRESS_REMAPTABDATA5_ADR_BASE                  1:0             /* RWEVF */
#define NV_INGRESS_REMAPTABDATA5_ADR_BASE_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_REMAPTABDATA5_ADR_LIMIT                 5:4             /* RWEVF */
#define NV_INGRESS_REMAPTABDATA5_ADR_LIMIT_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0                             0x000010b0      /* RW-4R */
#define NV_INGRESS_RIDTABDATA0_GSIZE                       3:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_GSIZE_16X                   0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_1X                    0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_2X                    0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_3X                    0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_4X                    0x00000004      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_5X                    0x00000005      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_6X                    0x00000006      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_7X                    0x00000007      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_8X                    0x00000008      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_9X                    0x00000009      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_10X                   0x0000000a      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_11X                   0x0000000b      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_12X                   0x0000000c      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_13X                   0x0000000d      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_14X                   0x0000000e      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_GSIZE_15X                   0x0000000f      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_PORT0                       10:5            /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_PORT0_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE0                    13:12           /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_VC_MODE0_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE0_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE0_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE0_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_PORT1                       19:14           /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_PORT1_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE1                    22:21           /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_VC_MODE1_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE1_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE1_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE1_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_PORT2                       28:23           /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_PORT2_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE2                    31:30           /* RWEVF */
#define NV_INGRESS_RIDTABDATA0_VC_MODE2_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE2_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE2_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA0_VC_MODE2_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA1                             0x000010b4      /* RW-4R */
#define NV_INGRESS_RIDTABDATA1_PORT3                       5:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_PORT3_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE3                    8:7             /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_VC_MODE3_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE3_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE3_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE3_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_PORT4                       14:9            /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_PORT4_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE4                    17:16           /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_VC_MODE4_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE4_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE4_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE4_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_PORT5                       23:18           /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_PORT5_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE5                    26:25           /* RWEVF */
#define NV_INGRESS_RIDTABDATA1_VC_MODE5_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE5_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE5_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA1_VC_MODE5_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA2                             0x000010b8      /* RW-4R */
#define NV_INGRESS_RIDTABDATA2_PORT6                       5:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_PORT6_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE6                    8:7             /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_VC_MODE6_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE6_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE6_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE6_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_PORT7                       14:9            /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_PORT7_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE7                    17:16           /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_VC_MODE7_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE7_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE7_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE7_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_PORT8                       23:18           /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_PORT8_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE8                    26:25           /* RWEVF */
#define NV_INGRESS_RIDTABDATA2_VC_MODE8_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE8_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE8_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA2_VC_MODE8_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA3                             0x000010bc      /* RW-4R */
#define NV_INGRESS_RIDTABDATA3_PORT9                       5:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_PORT9_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE9                    8:7             /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_VC_MODE9_SAME               0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE9_INVERT             0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE9_ALWAYS0            0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE9_ALWAYS1            0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_PORT10                      14:9            /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_PORT10_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE10                   17:16           /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_VC_MODE10_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE10_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE10_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE10_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_PORT11                      23:18           /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_PORT11_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE11                   26:25           /* RWEVF */
#define NV_INGRESS_RIDTABDATA3_VC_MODE11_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE11_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE11_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA3_VC_MODE11_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA4                             0x000010c0      /* RW-4R */
#define NV_INGRESS_RIDTABDATA4_PORT12                      5:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_PORT12_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE12                   8:7             /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_VC_MODE12_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE12_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE12_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE12_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_PORT13                      14:9            /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_PORT13_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE13                   17:16           /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_VC_MODE13_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE13_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE13_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE13_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_PORT14                      23:18           /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_PORT14_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE14                   26:25           /* RWEVF */
#define NV_INGRESS_RIDTABDATA4_VC_MODE14_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE14_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE14_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA4_VC_MODE14_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA5                             0x000010c4      /* RW-4R */
#define NV_INGRESS_RIDTABDATA5_PORT15                      5:0             /* RWEVF */
#define NV_INGRESS_RIDTABDATA5_PORT15_INIT                 0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA5_VC_MODE15                   8:7             /* RWEVF */
#define NV_INGRESS_RIDTABDATA5_VC_MODE15_SAME              0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA5_VC_MODE15_INVERT            0x00000001      /* RW--V */
#define NV_INGRESS_RIDTABDATA5_VC_MODE15_ALWAYS0           0x00000002      /* RW--V */
#define NV_INGRESS_RIDTABDATA5_VC_MODE15_ALWAYS1           0x00000003      /* RW--V */
#define NV_INGRESS_RIDTABDATA5_RMOD                        18:9            /* RWEVF */
#define NV_INGRESS_RIDTABDATA5_RMOD_INIT                   0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA5_ECC                         30:22           /* R-EVF */
#define NV_INGRESS_RIDTABDATA5_ECC_INIT                    0x00000000      /* R-E-V */
#define NV_INGRESS_RIDTABDATA5_ACLVALID                    31:31           /* RWEVF */
#define NV_INGRESS_RIDTABDATA5_ACLVALID_INVALID            0x00000000      /* RWE-V */
#define NV_INGRESS_RIDTABDATA5_ACLVALID_VALID              0x00000001      /* RW--V */
#define NV_INGRESS_RLANTABDATA0                            0x000010d0      /* RW-4R */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_0                 3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_0_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_0                  8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_0_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_1                 13:10           /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_1_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_1                  18:15           /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_1_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_2                 23:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SIZE_2_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_2                  28:25           /* RWEVF */
#define NV_INGRESS_RLANTABDATA0_GRP_SEL_2_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1                            0x000010d4      /* RW-4R */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_3                 3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_3_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_3                  8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_3_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_4                 13:10           /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_4_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_4                  18:15           /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_4_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_5                 23:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SIZE_5_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_5                  28:25           /* RWEVF */
#define NV_INGRESS_RLANTABDATA1_GRP_SEL_5_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2                            0x000010d8      /* RW-4R */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_6                 3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_6_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_6                  8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_6_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_7                 13:10           /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_7_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_7                  18:15           /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_7_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_8                 23:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SIZE_8_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_8                  28:25           /* RWEVF */
#define NV_INGRESS_RLANTABDATA2_GRP_SEL_8_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3                            0x000010dc      /* RW-4R */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_9                 3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_9_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_9                  8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_9_INIT             0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_10                13:10           /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_10_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_10                 18:15           /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_10_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_11                23:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SIZE_11_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_11                 28:25           /* RWEVF */
#define NV_INGRESS_RLANTABDATA3_GRP_SEL_11_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4                            0x000010e0      /* RW-4R */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_12                3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_12_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_12                 8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_12_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_13                13:10           /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_13_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_13                 18:15           /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_13_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_14                23:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SIZE_14_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_14                 28:25           /* RWEVF */
#define NV_INGRESS_RLANTABDATA4_GRP_SEL_14_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA5                            0x000010e4      /* RW-4R */
#define NV_INGRESS_RLANTABDATA5_GRP_SIZE_15                3:0             /* RWEVF */
#define NV_INGRESS_RLANTABDATA5_GRP_SIZE_15_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA5_GRP_SEL_15                 8:5             /* RWEVF */
#define NV_INGRESS_RLANTABDATA5_GRP_SEL_15_INIT            0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA5_RSVD                       21:20           /* RWEVF */
#define NV_INGRESS_RLANTABDATA5_RSVD_INIT                  0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA5_ECC                        30:22           /* R-EVF */
#define NV_INGRESS_RLANTABDATA5_ECC_INIT                   0x00000000      /* R-E-V */
#define NV_INGRESS_RLANTABDATA5_ACLVALID                   31:31           /* RWEVF */
#define NV_INGRESS_RLANTABDATA5_ACLVALID_INVALID           0x00000000      /* RWE-V */
#define NV_INGRESS_RLANTABDATA5_ACLVALID_VALID             0x00000001      /* RW--V */
#define NV_INGRESS_MCREMAPTABDATA0                         0x000010f0      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA0_RMAP_ADDR               12:0            /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA0_RMAP_ADDR_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA0_IRL_SEL                 16:15           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA0_IRL_SEL_SELECTNONE      0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA0_IRL_SEL_SELECTIRL0      0x00000001      /* RW--V */
#define NV_INGRESS_MCREMAPTABDATA0_IRL_SEL_SELECTIRL1      0x00000002      /* RW--V */
#define NV_INGRESS_MCREMAPTABDATA0_IRL_SEL_ENABLEERRRSP    0x00000003      /* RW--V */
#define NV_INGRESS_MCREMAPTABDATA0_ECC                     30:22           /* R-EVF */
#define NV_INGRESS_MCREMAPTABDATA0_ECC_INIT                0x00000000      /* R-E-V */
#define NV_INGRESS_MCREMAPTABDATA0_ACLVALID                31:31           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA0_ACLVALID_INVALID        0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA0_ACLVALID_VALID          0x00000001      /* RW--V */
#define NV_INGRESS_MCREMAPTABDATA1                         0x000010f4      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA1_REQCTXT_MSK             15:0            /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA1_REQCTXT_MSK_INIT        0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA1_REQCTXT_CHK             31:16           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA1_REQCTXT_CHK_INIT        0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA2                         0x000010f8      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA2_REQCTXT_REP             15:0            /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA2_REQCTXT_REP_INIT        0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA3                         0x000010fc      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA3_ADR_BASE                15:0            /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA3_ADR_BASE_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA3_ADR_LIMIT               31:16           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA3_ADR_LIMIT_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA4                         0x00001100      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA4_MCID                    6:0             /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA4_MCID_INIT               0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA4_RFUNC                   21:15           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA4_RFUNC_INIT              0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA4_ENB_REFLECT_MEM         22:22           /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA4_ENB_REFLECT_MEM_INIT    0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA5                         0x00001104      /* RW-4R */
#define NV_INGRESS_MCREMAPTABDATA5_ADR_BASE                1:0             /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA5_ADR_BASE_INIT           0x00000000      /* RWE-V */
#define NV_INGRESS_MCREMAPTABDATA5_ADR_LIMIT               5:4             /* RWEVF */
#define NV_INGRESS_MCREMAPTABDATA5_ADR_LIMIT_INIT          0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_STATUS_0                            0x00001400      /* RW-4R */
#define NV_INGRESS_ERR_STATUS_0_CMDDECODEERR               0:0             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_CMDDECODEERR_NONE          0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_CMDDECODEERR_CLEAR         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ECC_DBE_ERR   1:1             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ECC_DBE_ERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_REQCONTEXTMISMATCHERR      2:2             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_REQCONTEXTMISMATCHERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_REQCONTEXTMISMATCHERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_ACLFAIL                    3:3             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_ACLFAIL_NONE               0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_ACLFAIL_CLEAR              0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_LIMIT_ERR   4:4             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_LIMIT_ERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_LIMIT_ERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_DBE_ERR     5:5             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_DBE_ERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_HDR_ECC_DBE_ERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_INVALIDVCSET               6:6             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_INVALIDVCSET_NONE          0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_INVALIDVCSET_CLEAR         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_ADDRBOUNDSERR              7:7             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_ADDRBOUNDSERR_NONE         0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_ADDRBOUNDSERR_CLEAR        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RIDTABCFGERR               8:8             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RIDTABCFGERR_NONE          0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RIDTABCFGERR_CLEAR         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RLANTABCFGERR              9:9             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RLANTABCFGERR_NONE         0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RLANTABCFGERR_CLEAR        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_DBE_ERR       10:10           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_DBE_ERR_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_DBE_ERR         11:11           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_DBE_ERR_NONE    0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_DBE_ERR_CLEAR   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_DBE_ERR        12:12           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_DBE_ERR_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_DBE_ERR_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_PARITY_ERR          13:13           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_PARITY_ERR_NONE     0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_NCISOC_PARITY_ERR_CLEAR    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_LIMIT_ERR     14:14           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_REMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_LIMIT_ERR       15:15           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_LIMIT_ERR_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RIDTAB_ECC_LIMIT_ERR_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_LIMIT_ERR      16:16           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_LIMIT_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_RLANTAB_ECC_LIMIT_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_ADDRTYPEERR                17:17           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_ADDRTYPEERR_NONE           0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_ADDRTYPEERR_CLEAR          0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_INDEX_ERR     18:18           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_INDEX_ERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_INDEX_ERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_INDEX_ERR     19:19           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_INDEX_ERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_INDEX_ERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_INDEX_ERR       20:20           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_INDEX_ERR_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_INDEX_ERR_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ECC_DBE_ERR   21:21           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ECC_DBE_ERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ECC_DBE_ERR     22:22           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ECC_DBE_ERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23   /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24   /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25     /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ACLFAIL       26:26           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ACLFAIL_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ACLFAIL_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ACLFAIL       27:27           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ACLFAIL_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ACLFAIL_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ACLFAIL         28:28           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ACLFAIL_NONE    0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ACLFAIL_CLEAR   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ADDRBOUNDSERR 29:29           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTAREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ADDRBOUNDSERR 30:30           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_EXTBREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ADDRBOUNDSERR   31:31           /* RWDVF */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_0_MCREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0                            0x00001404      /* RW-4R */
#define NV_INGRESS_ERR_LOG_EN_0_CMDDECODEERR               0:0             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_CMDDECODEERR__PROD         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_CMDDECODEERR_DISABLE       0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_CMDDECODEERR_ENABLE        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ECC_DBE_ERR   1:1             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REQCONTEXTMISMATCHERR      2:2             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_REQCONTEXTMISMATCHERR__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REQCONTEXTMISMATCHERR__TPROD 0x00000000    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REQCONTEXTMISMATCHERR_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_REQCONTEXTMISMATCHERR_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ACLFAIL                    3:3             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_ACLFAIL__PROD              0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ACLFAIL__TPROD             0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ACLFAIL_DISABLE            0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_ACLFAIL_ENABLE             0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_LIMIT_ERR   4:4             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_LIMIT_ERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_DBE_ERR     5:5             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_DBE_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_DBE_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_HDR_ECC_DBE_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_INVALIDVCSET               6:6             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_INVALIDVCSET__PROD         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_INVALIDVCSET__TPROD        0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_INVALIDVCSET_DISABLE       0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_INVALIDVCSET_ENABLE        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRBOUNDSERR              7:7             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRBOUNDSERR__PROD        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRBOUNDSERR__TPROD       0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRBOUNDSERR_DISABLE      0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRBOUNDSERR_ENABLE       0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTABCFGERR               8:8             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTABCFGERR__PROD         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTABCFGERR_DISABLE       0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTABCFGERR_ENABLE        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTABCFGERR              9:9             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTABCFGERR__PROD        0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTABCFGERR_DISABLE      0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTABCFGERR_ENABLE       0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_DBE_ERR       10:10           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_DBE_ERR__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_DBE_ERR__TPROD 0x00000000     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_DBE_ERR         11:11           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_DBE_ERR__PROD   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_DBE_ERR_DISABLE 0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_DBE_ERR_ENABLE  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_DBE_ERR        12:12           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_DBE_ERR__PROD  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_DBE_ERR_DISABLE 0x00000000     /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_DBE_ERR_ENABLE 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_PARITY_ERR          13:13           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_PARITY_ERR__PROD    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_PARITY_ERR_DISABLE  0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_NCISOC_PARITY_ERR_ENABLE   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_LIMIT_ERR     14:14           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_REMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_LIMIT_ERR       15:15           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_LIMIT_ERR__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_LIMIT_ERR_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RIDTAB_ECC_LIMIT_ERR_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_LIMIT_ERR      16:16           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_LIMIT_ERR__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_LIMIT_ERR_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_RLANTAB_ECC_LIMIT_ERR_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRTYPEERR                17:17           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRTYPEERR__PROD          0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRTYPEERR__TPROD         0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRTYPEERR_DISABLE        0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_ADDRTYPEERR_ENABLE         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_INDEX_ERR     18:18           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_INDEX_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_INDEX_ERR__TPROD 0x00000000   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_INDEX_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_INDEX_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_INDEX_ERR     19:19           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_INDEX_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_INDEX_ERR__TPROD 0x00000000   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_INDEX_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_INDEX_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_INDEX_ERR       20:20           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_INDEX_ERR__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_INDEX_ERR__TPROD 0x00000000     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_INDEX_ERR_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_INDEX_ERR_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ECC_DBE_ERR   21:21           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ECC_DBE_ERR     22:22           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ECC_DBE_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23   /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24   /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25     /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ACLFAIL       26:26           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ACLFAIL__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ACLFAIL__TPROD 0x00000000     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ACLFAIL_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ACLFAIL_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ACLFAIL       27:27           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ACLFAIL__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ACLFAIL__TPROD 0x00000000     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ACLFAIL_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ACLFAIL_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ACLFAIL         28:28           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ACLFAIL__PROD   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ACLFAIL__TPROD  0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ACLFAIL_DISABLE 0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ACLFAIL_ENABLE  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR 29:29           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR 30:30           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ADDRBOUNDSERR   31:31           /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_0_MCREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0                   0x00001408      /* RW-4R */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_CMDDECODEERR      0:0             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_CMDDECODEERR__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_CMDDECODEERR_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_CMDDECODEERR_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR 1:1      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR 2:2         /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ACLFAIL           3:3             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ACLFAIL_DISABLE   0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ACLFAIL_ENABLE    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR 4:4      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR 5:5        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_INVALIDVCSET      6:6             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_INVALIDVCSET__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_INVALIDVCSET__TPROD 0x00000000    /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_INVALIDVCSET_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_INVALIDVCSET_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRBOUNDSERR     7:7             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRBOUNDSERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRBOUNDSERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTABCFGERR      8:8             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTABCFGERR_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTABCFGERR_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTABCFGERR     9:9             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTABCFGERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTABCFGERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR 10:10        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR 11:11          /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR 12:12         /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR 13:13           /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR 14:14      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR 15:15        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR 16:16       /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRTYPEERR       17:17           /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRTYPEERR_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_ADDRTYPEERR_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR 18:18      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR 19:19      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR 20:20        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR 21:21    /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR 22:22      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23 /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24 /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25 /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL 26:26        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL 27:27        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL 28:28          /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR 29:29  /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR 30:30  /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR 31:31    /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0               0x0000140c      /* RW-4R */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_CMDDECODEERR  0:0             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_CMDDECODEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_CMDDECODEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR 1:1  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR 2:2     /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ACLFAIL       3:3             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ACLFAIL__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ACLFAIL__TPROD 0x00000000     /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ACLFAIL_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ACLFAIL_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR 4:4  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR 5:5    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_HDR_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_INVALIDVCSET  6:6             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_INVALIDVCSET_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_INVALIDVCSET_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRBOUNDSERR 7:7             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTABCFGERR  8:8             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTABCFGERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTABCFGERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTABCFGERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTABCFGERR 9:9             /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTABCFGERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTABCFGERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTABCFGERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR 10:10    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR 11:11      /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR 12:12     /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR 13:13       /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_NCISOC_PARITY_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR 14:14  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_REMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR 15:15    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RIDTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR 16:16   /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_RLANTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRTYPEERR   17:17           /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRTYPEERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR 18:18  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR 19:19  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR 20:20    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR 21:21 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR 22:22  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL 26:26    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL 27:27    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL 28:28      /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR 29:29 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR 30:30 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR 31:31 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_0_MCREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CORRECTABLE_REPORT_EN_0             0x00001410      /* RW-4R */
#define NV_INGRESS_ERR_CONTAIN_EN_0                        0x00001414      /* RW-4R */
#define NV_INGRESS_ERR_CONTAIN_EN_0_CMDDECODEERR           0:0             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_CMDDECODEERR__PROD     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_CMDDECODEERR_DISABLE   0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_CMDDECODEERR_ENABLE    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ECC_DBE_ERR 1:1           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REQCONTEXTMISMATCHERR  2:2             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ACLFAIL                3:3             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ACLFAIL_DISABLE        0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ACLFAIL_ENABLE         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_LIMIT_ERR 4:4           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_DBE_ERR 5:5             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_HDR_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_INVALIDVCSET           6:6             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_INVALIDVCSET__PROD     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_INVALIDVCSET__TPROD    0x00000000      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_INVALIDVCSET_DISABLE   0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_INVALIDVCSET_ENABLE    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRBOUNDSERR          7:7             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRBOUNDSERR_DISABLE  0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRBOUNDSERR_ENABLE   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTABCFGERR           8:8             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTABCFGERR_DISABLE   0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTABCFGERR_ENABLE    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTABCFGERR          9:9             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTABCFGERR_DISABLE  0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTABCFGERR_ENABLE   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_DBE_ERR   10:10           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_DBE_ERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_DBE_ERR     11:11           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_DBE_ERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_DBE_ERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_DBE_ERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_DBE_ERR    12:12           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_DBE_ERR__PROD 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_DBE_ERR_ENABLE 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_PARITY_ERR      13:13           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_PARITY_ERR__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_PARITY_ERR_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_NCISOC_PARITY_ERR_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_LIMIT_ERR 14:14           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_REMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_LIMIT_ERR   15:15           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RIDTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_LIMIT_ERR  16:16           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_RLANTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRTYPEERR            17:17           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRTYPEERR_DISABLE    0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_ADDRTYPEERR_ENABLE     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_INDEX_ERR 18:18           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_INDEX_ERR 19:19           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_INDEX_ERR   20:20           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_INDEX_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_INDEX_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ECC_DBE_ERR 21:21         /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ECC_DBE_ERR 22:22           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ECC_DBE_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ECC_DBE_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ECC_DBE_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ECC_DBE_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23 /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24 /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25 /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ACLFAIL   26:26           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ACLFAIL   27:27           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ACLFAIL_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ACLFAIL_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ACLFAIL     28:28           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ACLFAIL_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ACLFAIL_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR 29:29       /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTAREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR 30:30       /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_EXTBREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ADDRBOUNDSERR 31:31         /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ADDRBOUNDSERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_0_MCREMAPTAB_ADDRBOUNDSERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0                             0x0000141c      /* RW-4R */
#define NV_INGRESS_ERR_FIRST_0_CMDDECODEERR                0:0             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_CMDDECODEERR_NONE           0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_CMDDECODEERR_CLEAR          0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ECC_DBE_ERR    1:1             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ECC_DBE_ERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_REQCONTEXTMISMATCHERR       2:2             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_REQCONTEXTMISMATCHERR_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_REQCONTEXTMISMATCHERR_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_ACLFAIL                     3:3             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_ACLFAIL_NONE                0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_ACLFAIL_CLEAR               0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_LIMIT_ERR    4:4             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_LIMIT_ERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_LIMIT_ERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_DBE_ERR      5:5             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_DBE_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_HDR_ECC_DBE_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_INVALIDVCSET                6:6             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_INVALIDVCSET_NONE           0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_INVALIDVCSET_CLEAR          0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_ADDRBOUNDSERR               7:7             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_ADDRBOUNDSERR_NONE          0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_ADDRBOUNDSERR_CLEAR         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RIDTABCFGERR                8:8             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RIDTABCFGERR_NONE           0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RIDTABCFGERR_CLEAR          0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RLANTABCFGERR               9:9             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RLANTABCFGERR_NONE          0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RLANTABCFGERR_CLEAR         0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_DBE_ERR        10:10           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_DBE_ERR_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_DBE_ERR_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_DBE_ERR          11:11           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_DBE_ERR_NONE     0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_DBE_ERR_CLEAR    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_DBE_ERR         12:12           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_DBE_ERR_NONE    0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_DBE_ERR_CLEAR   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_PARITY_ERR           13:13           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_PARITY_ERR_NONE      0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_NCISOC_PARITY_ERR_CLEAR     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_LIMIT_ERR      14:14           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_REMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_LIMIT_ERR        15:15           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_LIMIT_ERR_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RIDTAB_ECC_LIMIT_ERR_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_LIMIT_ERR       16:16           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_LIMIT_ERR_NONE  0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_RLANTAB_ECC_LIMIT_ERR_CLEAR 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_ADDRTYPEERR                 17:17           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_ADDRTYPEERR_NONE            0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_ADDRTYPEERR_CLEAR           0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_INDEX_ERR      18:18           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_INDEX_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_INDEX_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_INDEX_ERR      19:19           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_INDEX_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_INDEX_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_INDEX_ERR        20:20           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_INDEX_ERR_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_INDEX_ERR_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ECC_DBE_ERR    21:21           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ECC_DBE_ERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ECC_DBE_ERR      22:22           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ECC_DBE_ERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ECC_DBE_ERR_CLEAR 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR 23:23    /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR 24:24    /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_REQCONTEXTMISMATCHERR 25:25      /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_REQCONTEXTMISMATCHERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ACLFAIL        26:26           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ACLFAIL_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ACLFAIL_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ACLFAIL        27:27           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ACLFAIL_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ACLFAIL_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ACLFAIL          28:28           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ACLFAIL_NONE     0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ACLFAIL_CLEAR    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ADDRBOUNDSERR  29:29           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000  /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTAREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ADDRBOUNDSERR  30:30           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000  /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_EXTBREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ADDRBOUNDSERR    31:31           /* RWDVF */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ADDRBOUNDSERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_0_MCREMAPTAB_ADDRBOUNDSERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_HEADER_LOG_4                        0x00001430      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_4_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_4_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_5                        0x00001434      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_5_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_5_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_6                        0x00001438      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_6_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_6_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_7                        0x0000143c      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_7_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_7_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_8                        0x00001440      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_8_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_8_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_9                        0x00001444      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_9_DW                     31:0            /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_9_DW_INIT                0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_VALID                    0x00001448      /* R--4R */
#define NV_INGRESS_ERR_HEADER_LOG_VALID_HEADERVALID0       0:0             /* R-DVF */
#define NV_INGRESS_ERR_HEADER_LOG_VALID_HEADERVALID0_INVALID 0x00000000    /* R-D-V */
#define NV_INGRESS_ERR_HEADER_LOG_VALID_HEADERVALID0_VALID 0x00000001      /* R---V */
#define NV_INGRESS_ERR_TIMESTAMP_LOG                       0x0000144c      /* R--4R */
#define NV_INGRESS_ERR_TIMESTAMP_LOG_TIMESTAMP             23:0            /* R-DVF */
#define NV_INGRESS_ERR_TIMESTAMP_LOG_TIMESTAMP_INIT        0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_MISC_LOG_0                          0x00001450      /* R--4R */
#define NV_INGRESS_ERR_MISC_LOG_0_SPORT                    5:0             /* R-DVF */
#define NV_INGRESS_ERR_MISC_LOG_0_SPORT_INIT               0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_MISC_LOG_0_ENCODEDVC                10:8            /* R-DVF */
#define NV_INGRESS_ERR_MISC_LOG_0_ENCODEDVC_CREQ0          0x00000000      /* R-D-V */
#define NV_INGRESS_ERR_MISC_LOG_0_ENCODEDVC_RSP0           0x00000005      /* R---V */
#define NV_INGRESS_ERR_MISC_LOG_0_ENCODEDVC_CREQ1          0x00000006      /* R---V */
#define NV_INGRESS_ERR_MISC_LOG_0_ENCODEDVC_RSP1           0x00000007      /* R---V */
#define NV_INGRESS_ERR_ECC_CTRL                            0x00001470      /* RW-4R */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_HDR_ECC_ENABLE      0:0             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_HDR_ECC_ENABLE_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_HDR_ECC_ENABLE_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_HDR_ECC_ENABLE__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_PARITY_ENABLE       1:1             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_PARITY_ENABLE_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_PARITY_ENABLE_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_NCISOC_PARITY_ENABLE__PROD 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_MCREMAPTAB_ECC_ENABLE      5:5             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_MCREMAPTAB_ECC_ENABLE_ENABLE 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_MCREMAPTAB_ECC_ENABLE_DISABLE 0x00000000   /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_MCREMAPTAB_ECC_ENABLE__PROD 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTAREMAPTAB_ECC_ENABLE    6:6             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_EXTAREMAPTAB_ECC_ENABLE_ENABLE 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTAREMAPTAB_ECC_ENABLE_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTAREMAPTAB_ECC_ENABLE__PROD 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTBREMAPTAB_ECC_ENABLE    7:7             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_EXTBREMAPTAB_ECC_ENABLE_ENABLE 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTBREMAPTAB_ECC_ENABLE_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_EXTBREMAPTAB_ECC_ENABLE__PROD 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_REMAPTAB_ECC_ENABLE        8:8             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_REMAPTAB_ECC_ENABLE_ENABLE 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_REMAPTAB_ECC_ENABLE_DISABLE 0x00000000     /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_REMAPTAB_ECC_ENABLE__PROD  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_RIDTAB_ECC_ENABLE          9:9             /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_RIDTAB_ECC_ENABLE_ENABLE   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_RIDTAB_ECC_ENABLE_DISABLE  0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_RIDTAB_ECC_ENABLE__PROD    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_RLANTAB_ECC_ENABLE         10:10           /* RWEVF */
#define NV_INGRESS_ERR_ECC_CTRL_RLANTAB_ECC_ENABLE_ENABLE  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_ECC_CTRL_RLANTAB_ECC_ENABLE_DISABLE 0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_ECC_CTRL_RLANTAB_ECC_ENABLE__PROD   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER          0x00001480      /* RW-4R */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0         /* RWDVF */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER_LIMIT    0x00001484      /* RW-4R */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0   /* RWDVF */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS          0x00001488      /* R--4R */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0       /* R-DVF */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_VALID    0x0000148c      /* R--4R */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0          /* R-DVF */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_REMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER            0x00001490      /* RW-4R */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0           /* RWDVF */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER_LIMIT      0x00001494      /* RW-4R */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0     /* RWDVF */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS            0x00001498      /* R--4R */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0         /* R-DVF */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_VALID      0x0000149c      /* R--4R */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0            /* R-DVF */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_RIDTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER           0x000014a0      /* RW-4R */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0          /* RWDVF */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER_LIMIT     0x000014a4      /* RW-4R */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0    /* RWDVF */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS           0x000014a8      /* R--4R */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0        /* R-DVF */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_VALID     0x000014ac      /* R--4R */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0           /* R-DVF */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_RLANTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER        0x000014b0      /* RW-4R */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER_ERROR_COUNT 23:0       /* RWDVF */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER_LIMIT  0x000014b4      /* RW-4R */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0 /* RWDVF */
#define NV_INGRESS_ERR_NCISOC_HDR_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER      0x000014b8      /* RW-4R */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0     /* RWDVF */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER_LIMIT 0x000014bc     /* RW-4R */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0 /* RWDVF */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS      0x000014c0      /* R--4R */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0   /* R-DVF */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_VALID 0x000014c4     /* R--4R */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0      /* R-DVF */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_EXTAREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER      0x000014c8      /* RW-4R */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0     /* RWDVF */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER_LIMIT 0x000014cc     /* RW-4R */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0 /* RWDVF */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS      0x000014d0      /* R--4R */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0   /* R-DVF */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_VALID 0x000014d4     /* R--4R */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0      /* R-DVF */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_EXTBREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER        0x000014d8      /* RW-4R */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT 23:0       /* RWDVF */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER_ERROR_COUNT_INIT 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER_LIMIT  0x000014dc      /* RW-4R */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT 23:0 /* RWDVF */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_COUNTER_LIMIT_ERROR_LIMIT_INIT 0x00ffffff /* RWD-V */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS        0x000014e0      /* R--4R */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS 15:0     /* R-DVF */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_ERROR_ADDRESS_INIT 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_VALID  0x000014e4      /* R--4R */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID 0:0        /* R-DVF */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_INVALID 0x00000000 /* R-D-V */
#define NV_INGRESS_ERR_MCREMAPTAB_ECC_ERROR_ADDRESS_VALID_VALID_VALID 0x00000001 /* R---V */
#define NV_INGRESS_ERR_STATUS_1                            0x00001700      /* RW-4R */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ECC_LIMIT_ERR 0:0             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ECC_LIMIT_ERR 1:1             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000 /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ECC_LIMIT_ERR   2:2             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_MCCMDTOUCADDRERR           3:3             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_MCCMDTOUCADDRERR_NONE      0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_MCCMDTOUCADDRERR_CLEAR     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_READMCREFLECTMEMERR        4:4             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_READMCREFLECTMEMERR_NONE   0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_READMCREFLECTMEMERR_CLEAR  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ADDRTYPEERR   5:5             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ADDRTYPEERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_EXTAREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ADDRTYPEERR   6:6             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ADDRTYPEERR_NONE 0x00000000   /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_EXTBREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ADDRTYPEERR     7:7             /* RWDVF */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ADDRTYPEERR_NONE 0x00000000     /* RWD-V */
#define NV_INGRESS_ERR_STATUS_1_MCREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1                            0x00001704      /* RW-4R */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR 0:0             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR 1:1             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ECC_LIMIT_ERR   2:2             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCCMDTOUCADDRERR           3:3             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_MCCMDTOUCADDRERR__PROD     0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCCMDTOUCADDRERR__TPROD    0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCCMDTOUCADDRERR_DISABLE   0x00000000      /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_MCCMDTOUCADDRERR_ENABLE    0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_READMCREFLECTMEMERR        4:4             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_READMCREFLECTMEMERR__PROD  0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_READMCREFLECTMEMERR__TPROD 0x00000000      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_READMCREFLECTMEMERR_DISABLE 0x00000000     /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_READMCREFLECTMEMERR_ENABLE 0x00000001      /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ADDRTYPEERR   5:5             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ADDRTYPEERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTAREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ADDRTYPEERR   6:6             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ADDRTYPEERR__PROD 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_EXTBREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ADDRTYPEERR     7:7             /* RWEVF */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ADDRTYPEERR__PROD 0x00000001    /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ADDRTYPEERR__TPROD 0x00000000   /* RW--V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000  /* RWE-V */
#define NV_INGRESS_ERR_LOG_EN_1_MCREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1                   0x00001708      /* RW-4R */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR 0:0    /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR 1:1    /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR 2:2      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR  3:3             /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_READMCREFLECTMEMERR 4:4           /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_READMCREFLECTMEMERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_READMCREFLECTMEMERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR 5:5      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR 6:6      /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR 7:7        /* RWEVF */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1               0x0000170c      /* RW-4R */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR 0:0 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR 1:1 /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR 2:2  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR 3:3          /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCCMDTOUCADDRERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_READMCREFLECTMEMERR 4:4       /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_READMCREFLECTMEMERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_READMCREFLECTMEMERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_READMCREFLECTMEMERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_READMCREFLECTMEMERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR 5:5  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTAREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR 6:6  /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_EXTBREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR 7:7    /* RWEVF */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR__PROD 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR__TPROD 0x00000000 /* RW--V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_NON_FATAL_REPORT_EN_1_MCREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CORRECTABLE_REPORT_EN_1             0x00001710      /* RW-4R */
#define NV_INGRESS_ERR_CONTAIN_EN_1                        0x00001714      /* RW-4R */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR 0:0         /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR 1:1         /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ECC_LIMIT_ERR 2:2           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ECC_LIMIT_ERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCCMDTOUCADDRERR       3:3             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCCMDTOUCADDRERR_DISABLE 0x00000000    /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCCMDTOUCADDRERR_ENABLE 0x00000001     /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_READMCREFLECTMEMERR    4:4             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_READMCREFLECTMEMERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_READMCREFLECTMEMERR_ENABLE 0x00000001  /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ADDRTYPEERR 5:5           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTAREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ADDRTYPEERR 6:6           /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_EXTBREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ADDRTYPEERR 7:7             /* RWEVF */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ADDRTYPEERR_DISABLE 0x00000000 /* RWE-V */
#define NV_INGRESS_ERR_CONTAIN_EN_1_MCREMAPTAB_ADDRTYPEERR_ENABLE 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_1                             0x0000171c      /* RW-4R */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ECC_LIMIT_ERR  0:0             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000  /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ECC_LIMIT_ERR  1:1             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000  /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001 /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ECC_LIMIT_ERR    2:2             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ECC_LIMIT_ERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ECC_LIMIT_ERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_MCCMDTOUCADDRERR            3:3             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_MCCMDTOUCADDRERR_NONE       0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_MCCMDTOUCADDRERR_CLEAR      0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_READMCREFLECTMEMERR         4:4             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_READMCREFLECTMEMERR_NONE    0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_READMCREFLECTMEMERR_CLEAR   0x00000001      /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ADDRTYPEERR    5:5             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ADDRTYPEERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_EXTAREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ADDRTYPEERR    6:6             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ADDRTYPEERR_NONE 0x00000000    /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_EXTBREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001   /* RW--V */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ADDRTYPEERR      7:7             /* RWDVF */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ADDRTYPEERR_NONE 0x00000000      /* RWD-V */
#define NV_INGRESS_ERR_FIRST_1_MCREMAPTAB_ADDRTYPEERR_CLEAR 0x00000001     /* RW--V */
#endif // __ls10_dev_ingress_ip_h__
